==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/nl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
    "Storage invalid" : "Opslag ongeldig",
    "Unknown error" : "Onbekende fout",
    "All files" : "Alle bestanden",
    "Saved" : "Bewaard",
    "There was an error saving" : "Er trad een fout op bij opslaan",
    "File could not be found" : "Bestand kon niet worden gevonden",
    "Home" : "Thuis",
    "Close" : "Sluiten",
    "Favorites" : "Favorieten",
    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
    "Upload cancelled." : "Uploaden geannuleerd.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. U uploadt {size1}, maar is is slechts {size2} beschikbaar",
    "Target folder \"{dir}\" does not exist any more" : "Doelmap \"{dir}\" bestaat niet mee",
    "Not enough free space" : "Niet genoeg vrije ruimte beschikbaar",
    "Uploading..." : "Uploading...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Bestandsupload is bezig. Wanneer de pagina nu verlaten wordt, stopt de upload.",
    "Actions" : "Acties",
    "Download" : "Downloaden",
    "Rename" : "Naam wijzigen",
    "Delete" : "Verwijderen",
    "Disconnect storage" : "Verbinding met opslag verbreken",
    "Unshare" : "Stop met delen",
    "Could not load info for file \"{file}\"" : "Kon info voor bestand \"{file}\" niet laden",
    "Files" : "Bestanden",
    "Details" : "Details",
    "Select" : "Selecteer",
    "Pending" : "In behandeling",
    "Unable to determine date" : "Kon datum niet vaststellen",
    "Invalid path" : "Ongeldig pad",
    "This operation is forbidden" : "Deze taak is verboden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
    "{newName} already exists" : "{newName} bestaat al",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kon \"{fileName}\" niet hernoemen, het bestaat niet meer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{targetName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
    "Could not rename \"{fileName}\"" : "Kon \"{fileName}\" niet hernoemen",
    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
    "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
    "{dirs} and {files}" : "{dirs} en {files}",
    "_including %n hidden_::_including %n hidden_" : ["Inclusief %n verborgen","Inclusief %n verborgen"],
    "You don’t have permission to upload or create files here" : "U hebt geen toestemming om hier te uploaden of bestanden te maken",
    "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
    "New" : "Nieuw",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden ge-upload of gesynchroniseerd!",
    "Your storage is full, files can not be updated or synced anymore!" : "Uw opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Uw opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["komt overeen met '{filter}'","komen overeen met '{filter}'"],
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favoriet",
    "Favorite" : "Favoriet",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privélink: alleen personen die toegang hebben tot het bestand of de map kunnen deze gebruiken. Gebruik het als een permanente link voor uzelf of om anderen te verwijzen naar bestanden binnen shares.",
    "Folder" : "Map",
    "New folder" : "Nieuwe map",
    "{newname} already exists" : "{newname} bestaat al",
    "Upload" : "Uploaden",
    "An error occurred while trying to update the tags" : "Er trad een fout op bij uw poging de tags bij te werken",
    "A new file or folder has been <strong>created</strong>" : "Een nieuw bestand of map is <strong>aangemaakt</strong>",
    "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Beperk meldingen over aanmaken en wijzigen aan uw <strong>favoriete bestanden</strong> <em>(Alleen stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Een bestand of map is <strong>verwijderd</strong>",
    "A file or folder has been <strong>restored</strong>" : "Een bestand of een map is <strong>hersteld</strong>",
    "You created %1$s" : "Gecreëerd: %1$s",
    "%2$s created %1$s" : "%2$s creëerde %1$s",
    "%1$s was created in a public folder" : "%1$s werd gecreëerd in een openbare map",
    "You changed %1$s" : "Gewijzigd: %1$s",
    "%2$s changed %1$s" : "%2$s wijzigde %1$s",
    "You deleted %1$s" : "Verwijderd: %1$s",
    "%2$s deleted %1$s" : "%2$s verwijderde %1$s",
    "You restored %1$s" : "Hersteld: %1$s",
    "%2$s restored %1$s" : "%2$s herstelde %1$s",
    "Changed by %2$s" : "Gewijzigd door %2$s",
    "Deleted by %2$s" : "Verwijderd door %2$s",
    "Restored by %2$s" : "Hersteld door %2$s",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "Bestand",
    "Maximum upload size" : "Maximale bestandsgrootte voor uploads",
    "max. possible: " : "max. mogelijk: ",
    "Save" : "Bewaren",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Met PHP-FPM kan het 5 minuten duren voordat wijzigingen zijn doorgevoerd.",
    "Missing permissions to edit from here." : "Ontbrekende rechten om vanaf hier te bewerken.",
    "Settings" : "Instellingen",
    "Show hidden files" : "Tonen verborgen bestanden",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">om uw bestanden via WebDAV te benaderen</a>",
    "No files in here" : "Hier geen bestanden",
    "Upload some content or sync with your devices!" : "Upload bestanden of synchroniseer met uw apparaten!",
    "No entries found in this folder" : "Niets",
    "Select all" : "Alles selecteren",
    "Upload too large" : "Upload is te groot",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die u probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
    "No favorites" : "Geen favorieten",
    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die u favoriet vindt, worden hier getoond",
    "Text file" : "Tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files/l10n/nl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
    "Storage invalid" : "Opslag ongeldig",
    "Unknown error" : "Onbekende fout",
    "All files" : "Alle bestanden",
    "Saved" : "Bewaard",
    "There was an error saving" : "Er trad een fout op bij opslaan",
    "File could not be found" : "Bestand kon niet worden gevonden",
    "Home" : "Thuis",
    "Close" : "Sluiten",
    "Favorites" : "Favorieten",
    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
    "Upload cancelled." : "Uploaden geannuleerd.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. U uploadt {size1}, maar is is slechts {size2} beschikbaar",
    "Target folder \"{dir}\" does not exist any more" : "Doelmap \"{dir}\" bestaat niet mee",
    "Not enough free space" : "Niet genoeg vrije ruimte beschikbaar",
    "Uploading..." : "Uploading...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Bestandsupload is bezig. Wanneer de pagina nu verlaten wordt, stopt de upload.",
    "Actions" : "Acties",
    "Download" : "Downloaden",
    "Rename" : "Naam wijzigen",
    "Delete" : "Verwijderen",
    "Disconnect storage" : "Verbinding met opslag verbreken",
    "Unshare" : "Stop met delen",
    "Could not load info for file \"{file}\"" : "Kon info voor bestand \"{file}\" niet laden",
    "Files" : "Bestanden",
    "Details" : "Details",
    "Select" : "Selecteer",
    "Pending" : "In behandeling",
    "Unable to determine date" : "Kon datum niet vaststellen",
    "Invalid path" : "Ongeldig pad",
    "This operation is forbidden" : "Deze taak is verboden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
    "{newName} already exists" : "{newName} bestaat al",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kon \"{fileName}\" niet hernoemen, het bestaat niet meer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{targetName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
    "Could not rename \"{fileName}\"" : "Kon \"{fileName}\" niet hernoemen",
    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
    "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
    "{dirs} and {files}" : "{dirs} en {files}",
    "_including %n hidden_::_including %n hidden_" : ["Inclusief %n verborgen","Inclusief %n verborgen"],
    "You don’t have permission to upload or create files here" : "U hebt geen toestemming om hier te uploaden of bestanden te maken",
    "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
    "New" : "Nieuw",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden ge-upload of gesynchroniseerd!",
    "Your storage is full, files can not be updated or synced anymore!" : "Uw opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Uw opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["komt overeen met '{filter}'","komen overeen met '{filter}'"],
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favoriet",
    "Favorite" : "Favoriet",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Privélink: alleen personen die toegang hebben tot het bestand of de map kunnen deze gebruiken. Gebruik het als een permanente link voor uzelf of om anderen te verwijzen naar bestanden binnen shares.",
    "Folder" : "Map",
    "New folder" : "Nieuwe map",
    "{newname} already exists" : "{newname} bestaat al",
    "Upload" : "Uploaden",
    "An error occurred while trying to update the tags" : "Er trad een fout op bij uw poging de tags bij te werken",
    "A new file or folder has been <strong>created</strong>" : "Een nieuw bestand of map is <strong>aangemaakt</strong>",
    "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Beperk meldingen over aanmaken en wijzigen aan uw <strong>favoriete bestanden</strong> <em>(Alleen stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Een bestand of map is <strong>verwijderd</strong>",
    "A file or folder has been <strong>restored</strong>" : "Een bestand of een map is <strong>hersteld</strong>",
    "You created %1$s" : "Gecreëerd: %1$s",
    "%2$s created %1$s" : "%2$s creëerde %1$s",
    "%1$s was created in a public folder" : "%1$s werd gecreëerd in een openbare map",
    "You changed %1$s" : "Gewijzigd: %1$s",
    "%2$s changed %1$s" : "%2$s wijzigde %1$s",
    "You deleted %1$s" : "Verwijderd: %1$s",
    "%2$s deleted %1$s" : "%2$s verwijderde %1$s",
    "You restored %1$s" : "Hersteld: %1$s",
    "%2$s restored %1$s" : "%2$s herstelde %1$s",
    "Changed by %2$s" : "Gewijzigd door %2$s",
    "Deleted by %2$s" : "Verwijderd door %2$s",
    "Restored by %2$s" : "Hersteld door %2$s",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "Bestand",
    "Maximum upload size" : "Maximale bestandsgrootte voor uploads",
    "max. possible: " : "max. mogelijk: ",
    "Save" : "Bewaren",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Met PHP-FPM kan het 5 minuten duren voordat wijzigingen zijn doorgevoerd.",
    "Missing permissions to edit from here." : "Ontbrekende rechten om vanaf hier te bewerken.",
    "Settings" : "Instellingen",
    "Show hidden files" : "Tonen verborgen bestanden",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">om uw bestanden via WebDAV te benaderen</a>",
    "No files in here" : "Hier geen bestanden",
    "Upload some content or sync with your devices!" : "Upload bestanden of synchroniseer met uw apparaten!",
    "No entries found in this folder" : "Niets",
    "Select all" : "Alles selecteren",
    "Upload too large" : "Upload is te groot",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die u probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
    "No favorites" : "Geen favorieten",
    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die u favoriet vindt, worden hier getoond",
    "Text file" : "Tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt",
    "Target folder does not exist any more" : "Doelmap bestaat niet mee",
    "Upload timeout for file \"{file}\"" : "Upload timeout voor bestand \"{file}\"",
    "Processing files..." : "Verwerken bestanden...",
    "No entries in this folder match {filter}" : "Niets in deze map komt overeen met {filter}"
},
"nplurals=2; plural=(n != 1);");
